Changelog
=========

0.0.1 (2020-05-25)
------------------
* First release on PyPI.

0.0.5 (2020-006-06)
------------------
* Implemented smooth start and stop machinery to the workers.

0.0.6 (2020-006-07)
------------------
* Added start(), renamed quit_all_workers() to quit()
* Added send(), add_to_send_queue(), process_send_queue()
